# SEO Checklist Automation Guide

This guide explains how to use the automated SEO checklist verification system that automatically marks completed tasks in the SEO checklist when blog posts are created or modified.

## Overview

The automated checklist system:
- Automatically verifies blog posts against SEO checklist items
- Marks completed items in the SEO checklist
- Adds completed blog posts to the "Completed Blog Posts" section
- Provides feedback on items that need attention

## How It Works

1. When a new blog post is created in the `content/blog/` directory, the system analyzes it against the SEO checklist criteria.
2. The system checks each item in the checklist and marks those that pass verification with [x].
3. The blog post is added to the "Completed Blog Posts" section with its title and date.
4. If any items fail verification, the system provides feedback on what needs to be fixed.

## Starting the Automation

To start the automated verification:

This will start the automation in the background and watch for changes to blog post files.

## Stopping the Automation


## Verification Rules

The system checks blog posts against these criteria:

### Keyword Optimization
- Primary keyword appears in title, H1, first paragraph, and meta description
- Keyword density falls within 1.5-2% for primary keywords
- Secondary keywords used naturally throughout content

### Content Structure
- Single H1 with primary keyword
- Logical hierarchy of H2 and H3 headings
- Presence of Key Takeaways section
- Comprehensive content addressing user intent
- Concise paragraphs
- Structured elements (lists, tables, code blocks)

### Technical SEO
- Meta description length and keyword presence
- SEO-friendly URL with target keyword
- Image alt text with keywords
- Internal and external links
- Page load optimization

### Schema Markup
- Appropriate schema.org markup
- Article, FAQ, and HowTo schema as appropriate

### User Experience
- Readability and scan-friendliness
- Mobile responsiveness
- No spelling or grammar errors
- Functional links and images

### Content Quality
- Factual accuracy and currentness
- Unique value proposition
- Appropriate writing style
- Fulfillment of title promise
- Clear call-to-action

## Manual Verification

While the system automates most verification, some aspects still require manual review:
- Factual accuracy verification
- Subjective quality assessment
- Link functionality testing
- Mobile display testing

## Customizing the Automation

To customize the verification rules:

1. Edit the functions in `docs/auto-checklist-script.js`
2. Modify the rule definitions in `rules/auto-checklist-verification.mdc`

## Troubleshooting

If the automation is not working correctly:

1. Check that Node.js is installed and up-to-date
2. Ensure the gray-matter package is installed
3. Check the system logs for errors
4. Restart the automation using the start script

For persistent issues, examine the auto-checklist-script.js file directly to identify potential problems. 